#
# spec file for package redsea
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           redsea
Version:        0.20
Release:        bp155.2.11
Summary:        An RDS decoder
License:        MIT
Group:          Productivity/Hamradio/Other
URL:            https://github.com/windytan/redsea
#Git-Clone:     https://github.com/windytan/redsea.git
Source:         https://github.com/windytan/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libliquid-devel
BuildRequires:  libsndfile-devel
Recommends:     jq
Recommends:     rtl-sdr

%description
redsea is a command-line RDS (Radio Data System) decoder.
It can be used with any RTL-SDR USB radio stick with the rtl_fm tool.
It can also decode the raw ASCII bitstream, the hex format used by RDS Spy,
and audio files containing multiplex signals (MPX).

RDS groups are printed to the terminal as line-delimited JSON objects
or, optionally, undecoded hex blocks (-x).

%prep
%setup -q

%build
autoreconf -fiv
export CXXFLAGS='%{optflags} -Wno-return-type'
%configure
%make_build

%install
%make_install
rm %{buildroot}/%{_datadir}/doc/redsea/README.md

%files
%license LICENSE
%doc CHANGES.md README.md
%{_bindir}/redsea

%changelog
* Mon Mar  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.20
  * Recognize more ODAs and features.
  * Add support for PTY names (group 10A).
  * Add partial support for DAB cross-referencing.
  * Add support for raw broadcaster data in EON (variant 15).
  * Add support for transparent data channels (groups 5A, 5B).
  * Add support for fractional seconds in the rx timestamp
    format (%%f).
  * Add support for TMC tuning info variant 8.
  * Add buffer delay compensation to rx timestamps. Timestamps
    aim to represent the time the PCM samples were read in.
  * Place some JSON fields in the beginning of the line for
    easier visual inspection (pi, group, ps...).
  * Print raw ODA data if the application is not supported.
* Mon Apr  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.19
  * Add option --show-raw (-R) for including the raw group data
    as a hex string in the JSON output
  * Print usage help if there are non-option arguments on the
    command line
  * Fix uninitialized block error rate values on some systems
  * Update jsoncpp from 1.8.1 to 1.8.4 to fix some warnings
* Sun May 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.18
  * Add support for loading multiple TMC location databases by
    specifying --loctable more than once.
  * Sample rate can also be specified as -r 171k instead of -r 171000.
  * Fix a crash if the input audio file couldn't be loaded.
  * Print usage help instead of error message when stdin is empty.
  * Speed up loading of TMC location database.
  * Improve block sync detection by ignoring spurious sync pulses.
  * Fine-tune filter bandwidths for better sensitivity, based on
    test runs.
  * At EOF, process the last partially received group.
  * Remove character codetables G1 and G2 since they don't appear
    in the latest RDS standard any more.
  * Clean up code to ensure maintainability. Redsea now requires
    a compiler that supports C++14.
* Fri Dec 14 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias, extend description.
* Fri Jun  8 2018 mardnh@gmx.de
- Update to version 0.17.1
  Bugfix release.
  * Return exit value 0 if --version or --help was requested
  * Don't open stdout for libsndfile unless --feed-through was
    specified, otherwise json can't be written (this may break the
    feed-through on Linux temporarily)
* Tue Jun  5 2018 mardnh@gmx.de
- Update to version 0.17.0
  * Change the type of the JSON field for TMC message urgency, from
    integer (0, 1, 2) to string ("none", "U", "X"), to better match
    its values in the specification
  * Speed improvements by avoiding a few extraneous buffer copies
    internally
* Tue Mar 27 2018 mardnh@gmx.de
- Update to version 0.16.0
  * Add support for multi-channel signals (--channels) - libsndfile
    is now a required dependency
  * Speed improvements: ◦By using a lookup table instead of sinf/cosf
    to generate the mix-down sinusoid
  * By only using one mix-down operation instead of two
* Wed Jan 31 2018 mardnh@gmx.de
- Update to version 0.15.0
  * Add prog_item_number field containing the raw Program Item Number
  * Add partial_alt_kilohertz field containing an incomplete list of
    alternative frequencies when the --show-partial option is used
  * Add configure option --without-macports to disable directory checks
    when cross-compiling
  * Reduce write calls to output JSON stream using a streamstring
* Sat Dec  9 2017 mardnh@gmx.de
- Update to version 0.14.1
  * Don't consider UTC+14 invalid (it's the time zone in Kiribati)
  * Use JSON object callsign_uncertain for call signs of stations whose
  * PI code begins with a 1
  * Fix syntax errors in schema
* Thu Nov 16 2017 mardnh@gmx.de
- Update to version 0.14
  * Added support for decoding call sign letters from North American
    (RBDS) stations - activated by the -u switch. These are very
    noise-resistant as they're based on the PI code.
* Tue Sep 19 2017 mardnh@gmx.de
- Update to version 0.13
  * Change the JSON structure in radiotext_plus: RT+ tags are now displayed as
    an array of objects with content-type and data
  * Change the way frequencies are displayed for better machine readability, from
    "frequency":"87.9 MHz" to "kilohertz":87900
  * Update jsoncpp from version 1.7.7 to 1.8.1
* Sat Jul 22 2017 mardnh@gmx.de
- Update to version 0.12
  * Add support for time-of-demodulation timestamps (-t, --timestamp)
  * Add support for average block error rate (BLER) estimation (-E, --bler)
  * Change the long option for -b to --input-bits and fix the incorrect
    option in the usage help
* Mon Apr 17 2017 mardnh@gmx.de
- Update to version 0.11
  * Add support for TMC alternative frequencies (tuning info variant 6)
  * Add support for TMC gap parameter and enhanced mode (3A group variant 1)
  * Change JSON schema for TMC: encryption_id is now under system_info
  * Change PLL bandwidth and lowpass cutoff frequency to improve noise performance
  * Change resampler anti-alias cutoff frequency to allow for lower sample rates
  * Fix missing zero-padding in PIN time string
  * Fix uninitialized PI field occasionally getting printed when the actual PI is missed
  * Fix some names not getting read properly from the location database
  * Fix grammar in some TMC event descriptions
  * Fix potentially uninitialized data printout when a type 6B group was not fully received
  * Fix potentially uninitialized RadioText+ tags when the group was not fully received
  * Fix spurious printouts of "version B" groups when the C' offset was not seen
* Mon Apr  3 2017 mardnh@gmx.de
- initial package, version 0.10.0
